Module attribute

Module attribute 

Span attribute helpers. Span attribute helpers shared by tracing and OpenTelemetry integrations.

Enums

SpanAttributeValue
Value that can be attached to an observability span attribute.

Functions

record_current_span_attribute
Record a tracing field and set an OpenTelemetry attribute on the current span.
record_span_attribute
Record a tracing span field and set the same OpenTelemetry span attribute.
set_current_span_attribute
Set an OpenTelemetry attribute on the current span.
set_span_attribute
Set an OpenTelemetry span attribute on a tracing span.