Span attribute helpers. Span attribute helpers shared by tracing and OpenTelemetry integrations.
Enums
- Span
Attribute Value - Value that can be attached to an observability span attribute.
Functions
- record_
current_ span_ attribute - Record a tracing field and set an OpenTelemetry attribute on the current span.
- record_
span_ attribute - Record a tracing span field and set the same OpenTelemetry span attribute.
- set_
current_ span_ attribute - Set an OpenTelemetry attribute on the current span.
- set_
span_ attribute - Set an OpenTelemetry span attribute on a tracing span.